{% extends "valet_keys/base.html" %} {% block subcontent %}

Return to the key list

Created
  {{ key.created }}
Description
  {{ key.description }}

{% if not items.object_list|length %}

This key has not been used yet.

{% else %}

Time | Action | Object | Notes
--- | --- | --- | ---
{% for item in items.object_list %}
{{ item.created }} | {{ item.action }} | {% if item.content_object.get_absolute_url %} {{ item.content_object }} {% else %} {{ short_desc }} {% endif %} | {{ item.notes }}
{% endfor %}

{% endif %} {% endblock %}